/*
 * $Id: termin.unx.h 673 2007-08-16 22:25:10Z hubert@u.washington.edu $
 *
 * ========================================================================
 * Copyright 2006-2007 University of Washington
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * ========================================================================
 */

#ifndef PINE_OSDEP_TERMIN_UNX_INCLUDED
#define PINE_OSDEP_TERMIN_UNX_INCLUDED


#include <general.h>


/* exported prototypes */
void		tty_chmod(struct pine *, int, int);



#endif /* PINE_OSDEP_TERMIN_UNX_INCLUDED */
